@@ -208,7 +208,8 @@ class Netgear(object):
                     if not success:
                         err_mess = (
                             "503 Service Unavailable after retry, "
-                            "the API may be overloaded."
+                            "the API may be overloaded '%s', '%s'."
+                            % (service, method)
                         )
                 elif h.is_service_not_found_response(response):
                     err_mess = (
@@ -217,8 +218,10 @@ class Netgear(object):
                     )
                 else:
                     err_mess = (
-                        "Invalid response: %s\n%s\n%s"
-                        % (response.status_code,
+                        "Invalid response to '%s', '%s': %s\n%s\n%s"
+                        % (service,
+                           method,
+                           response.status_code,
                            str(response.headers),
                            response.text)
                     )
@@ -229,13 +232,27 @@ class Netgear(object):
                 _LOGGER.debug(err_mess)
 
             return success, response
-
+        except requests.exceptions.ReadTimeout as err:
+            if not self._logging_in:
+                _LOGGER.error(
+                    "Netgear ReadTimeout, service '%s', method '%s', "
+                    "host %s:%s ssl %s"
+                    % (service, method, self.host, self.port, self.ssl)
+                )
+            else:
+                _LOGGER.debug("ReadTimeout while logging in "
+                              "port %s ssl %s: %s", self.port, self.ssl, err)
         except requests.exceptions.RequestException as err:
             if not self._logging_in:
-                _LOGGER.exception("Error talking to API")
+                _LOGGER.exception(
+                    "Error talking to API with service '%s' "
+                    "method '%s' host %s:%s ssl %s"
+                    % (service, method, self.host, self.port, self.ssl)
+                )
             else:
                 _LOGGER.debug("RequestException while logging in "
-                              "port %s ssl %s: %s", self.port, self.ssl, err)
+                              "host %s:%s ssl %s: %s",
+                              self.host, self.port, self.ssl, err)
             self.cookie = None
 
             # Maybe one day we will distinguish between
